pub struct Directive {
pub line: usize,
pub comment: Comment,
pub components: Vec<Component>,
pub command: Option<Command>,
}Expand description
Any command that is given to the linter using an inline comment.
Fields
line: usizeThe line number in which the directive comment was parsed.
comment: Commentcomponents: Vec<Component>command: Option<Command>Contains the parsed Command, but is None if the components
failed to be parsed as a valid Command.
Implementations