get_inferable_rules

Function get_inferable_rules 

pub fn get_inferable_rules() -> Vec<Box<dyn Inferable>>
Get all of the built in rules which can have their options inferred using multiple syntax nodes see Inferable for more information.