Module groups

Module groups 

All of the groups of built in rules in the linter.

Re-exports

pub use errors::errors;
pub use regex::regex;
pub use style::style;

Modules

errors
Rules which relate to productions which are almost always erroneous or cause unexpected behavior.
regex
Rules which relate to regular expressions.
style
Rules which relate to code style and formatting.