pub struct LintResult<'s> {
pub parser_diagnostics: Vec<Diagnostic>,
pub rule_results: HashMap<&'static str, RuleResult>,
pub directive_diagnostics: Vec<DirectiveError>,
pub store: &'s CstRuleStore,
pub parsed: SyntaxNode,
pub file_id: usize,
pub verbose: bool,
pub fixed_code: Option<String>,
}Expand description
The result of linting a file.
Fields
parser_diagnostics: Vec<Diagnostic>Any diagnostics (errors, warnings, etc) emitted from the parser
rule_results: HashMap<&'static str, RuleResult>The diagnostics emitted by each rule run
directive_diagnostics: Vec<DirectiveError>Any warnings or errors emitted by the directive parser
store: &'s CstRuleStoreparsed: SyntaxNodefile_id: usizeverbose: boolfixed_code: Option<String>Implementations
Sourceimpl LintResult<'_>
impl LintResult<'_>
Sourcepub fn diagnostics(&self) -> impl Iterator<Item = &Diagnostic>
pub fn diagnostics(&self) -> impl Iterator<Item = &Diagnostic>
Get all of the diagnostics thrown during linting, in the order of parser diagnostics, then the diagnostics of each rule sequentially.