Inferable

Trait Inferable 

pub trait Inferable:
    CstRule
    + Serialize
    + Deserialize {
    // Required method
    fn infer(&mut self, nodes: &[SyntaxNode]);
}
A trait describing rules for which their configuration can be automatically deduced (inferred) using parsed syntax trees

Required Methods

fn infer(&mut self, nodes: &[SyntaxNode])

Infer the options for the rule from multiple nodes (which may be from different trees) and change them